"""
Image classifier based on Inference Engine
"""

import cv2
import numpy as np
from openvino.inference_engine import IENetwork, IECore


class InferenceEngineClassifier:
    def __init__(self, configPath=None, weightsPath=None,
            device='CPU', extension=None, classesPath=None):
        self.weights = weightsPath
        self.config = configPath
        self.ie = IECore()
        self.net = IENetwork(model=configPath, weights=weightsPath)
        if extension:
            self.ie.add_extension(extension, 'CPU')
        self.exec_net = self.ie.load_network(network=self.net,
                                             device_name=device)
        if classesPath:
            self.classes = [line.rstrip('\n') for line in open(classesPath)]
        return

    def get_top(self, prob, topN=1):
        prob = prob[0]
        best_n = np.argsort(prob)[-topN:]
        result = []
        for i in range(len(best_n)-1, -1, -1):
            try:
                classname = self.classes[best_n[i]]
            except:
                classname = best_n[i]
            line = [classname, prob[best_n[i]] * 100.0]
            result.append(line)
        return result

    def _prepare_image(self, image, h, w):
        if image.shape[:-1] != (h, w):
            image = cv2.resize(image, (w, h))
        image = image.transpose((2, 0, 1))
        return image

    def classify(self, image):
        input_blob = next(iter(self.net.inputs))
        out_blob = next(iter(self.net.outputs))
        n, c, h, w = self.net.inputs[input_blob].shape
        blob = self._prepare_image(image, h, w)
        output = self.exec_net.infer(inputs={input_blob: blob})
        return output[out_blob]
