"""
Videoanalytics class
"""
import cv2
import numpy as np


class Videoanalytics():
    def __init__(self, classIds, classesPath=None):
        self.classIds = classIds
        if classesPath:
            self.classes = [line.rstrip('\n') for line in open(classesPath)]
        return

    def count_objects_per_classes(self, tracker):
        results = {}
        for tracklet in tracker._tracks:
            # Get object class from tracklet
            classid = tracklet[-1].class_id
            # Add +1 to counter for object
            if classid in self.classIds:
                if classid in results:
                    results[classid] += 1
                else:
                    results[classid] = 1
        return results

    def draw_videoanalytics(self, frame, tracker):
        (h, w) = frame.shape[:2]

        # Draw detections of chosen classes
        for tracklet in tracker._tracks:
            # Get object class from tracklet
            classid = int(tracklet[-1].class_id)
            if classid in self.classIds:
                # Draw bbox of the last detection
                x_left = int(tracklet[-1].x_left * w)
                y_bottom = int(tracklet[-1].y_bottom * h)
                x_right = int(tracklet[-1].x_right * w)
                y_top = int(tracklet[-1].y_top * h)
                cv2.rectangle(frame, (x_left, y_bottom), (x_right, y_top),
                    (0, 255, 0), 2)
        
        # Draw tracklets of chosen classes
        for track in tracker._tracks:
            # Get object class from tracklet
            classid = int(track[-1].class_id)
            if classid in self.classIds:
            # Draw one tracklet from segments 
                for i in range(len(track)-1):
                    x1 = int((track[i].x_left + track[i].x_right) * w) // 2
                    y1 = int((track[i].y_bottom + track[i].y_top) * h) // 2
                    x2 = int((track[i+1].x_left + track[i+1].x_right) * w) // 2
                    y2 = int((track[i+1].y_bottom + track[i+1].y_top) * h) // 2
                    cv2.line(img=frame, pt1=(x1,y1), pt2=(x2,y2), 
                        color=(0, 255, 0), thickness=3)

        # Draw statistics
        counts = self.count_objects_per_classes(tracker)
        for i, elem in enumerate(counts):
            if self.classes:
                id = int(elem)
                text = 'Class {}: {} objects'.format(
                    self.classes[id], counts[elem])
            else:
                text = 'Class {}: {} objects'.format(elem, counts[elem])
            text_pos = (0, i * 30 + 30)
            cv2.putText(frame, text, text_pos,
                        cv2.FONT_HERSHEY_COMPLEX, 1.0, (0, 255, 255), 2)
        return frame
